@@ -1,7 +1,7 @@
 ## Graph.pm is a graphing package that supports on-the-fly graphing 
 ## from the gnuplot, XRT, and Xmgrace graphing packages.
 ##
-## $Id: Graph.pm,v 1.45 2006/04/18 17:56:47 emile Exp $ $Name:  $
+## $Id: Graph.pm,v 1.52 2015/10/05 20:35:33 rkoga Exp $ $Name: Chart-Graph-Release-3-3-1 $
 ##
 ## This software product is developed by Michael Young and David Moore,
 ## and copyrighted(C) 1998 by the University of California, San Diego
@@ -39,15 +39,15 @@
 package Chart::Graph;
 use Exporter();
 
-$VERSION = '3.0';
+$VERSION = '3.3.1';
 @ISA = qw(Exporter);
 @EXPORT = qw();
 @EXPORT_OK = qw(&gnuplot &xrt3d &xrt2d &xmgrace);
 
-$cvs_Id = '$Id: Graph.pm,v 1.45 2006/04/18 17:56:47 emile Exp $';
-$cvs_Author = '$Author: emile $';
-$cvs_Name = '$Name:  $';
-$cvs_Revision = '$Revision: 1.45 $';
+$cvs_Id = '$Id: Graph.pm,v 1.52 2015/10/05 20:35:33 rkoga Exp $';
+$cvs_Author = '$Author: rkoga $';
+$cvs_Name = '$Name: Chart-Graph-Release-3-3-1 $';
+$cvs_Revision = '$Revision: 1.52 $';
 
 use Chart::Graph::Utils qw(:USER);
 use Chart::Graph::Gnuplot qw(&gnuplot);
@@ -127,16 +127,16 @@ Chart::Graph - Perl extension for a front-end to gnuplot, XRT, and Xmgrace.
  use Chart::Graph;
 
 Graph.pm is a wrapper module that allows easy generation of graphs
-within perl. Currently Graph.pm supports three graphing packages,
+within Perl. Currently Graph.pm supports three graphing packages:
 gnuplot, XRT, and Xmgrace.  These software packages must be obtained
 separately from this Perl module.  Information on each graphing
-package and it's availability is provided in the documentation on that
-module.  Gnuplot and Xmgrace are freely available software pages for
+package and its availability is provided in the documentation on that
+module.  Gnuplot and Xmgrace are freely available software for
 UNIX systems.  XRT is a commercial product.
 
-Currently the xrt3d and xrt2d package is not being supported,
-although it works. It is still in the development stage. Feel free
-to give it a try though.
+Currently the xrt3d and xrt2d package are not being supported,
+although they work. They are still in the development stage. Feel free
+to give them a try though.
 
 
 =head1 INSTALLATION
@@ -159,15 +159,14 @@ install Graph.pm on your system you need to run:
          make test
          make install
 
-The standard Perl options apply. For example you can specify the
-location of you Perl Installation by the option:
-C<PREFIX=/home/your/private/dir>.  Which results modifying the first
-command as follows:
+The standard Perl options apply. For example, you can specify the
+location of your Perl installation with the option
+C<PREFIX=/your/private/dir>, by modifying the first command as follows:
 
          perl Makefile.PL PREFIX=/your/private/dir
 
-Running the Makefile.PL Perl script mades some additional preparation
-before creating the the Makefile.  In particular, the script sets up
+Running the Makefile.PL Perl script does some additional preparation
+before creating the Makefile.  In particular, the script sets up
 the testing routines for the various graphics modules.
 
         Enter (space separated) graphing drivers to test: [gnuplot xrt3d xrt2d xmgrace]
@@ -182,7 +181,7 @@ to a X virtual frame buffer.
         Enter path to X virtual frame buffer(Xvfb):
 
 
-Finally, If you are running XRT, you need to provide that path to the
+Finally, if you are running XRT, you need to provide that path to the
 XRT binaries:
 
         Enter path to xrt2d binary (built from xrt2d/):
@@ -190,7 +189,7 @@ XRT binaries:
 Note that running the tests will create image files that are placed in
 the directory F<test_results>.  These images are almost all identical
 with the examples provided with the documentation and can be used to
-check if there are subtile errors in your image creation software.
+check if there are subtle errors in your image creation software.
 
 =head1 USAGE
 
@@ -201,8 +200,8 @@ interface cannot be entirely uniform.
 
 =head2 GENERAL DIAGNOSTICS AND TOOLS
 
-Currently Chart::Graph supports two levels of debug, C<0> (no debug msgs)
-and C<1>(debug msgs). You need to set the C<$Chart::Graph::debug> flag
+Currently Chart::Graph supports two levels of debugging, C<0> (no debug msgs)
+and C<1> (debug msgs). You need to set the C<$Chart::Graph::debug> flag
 accordingly. If you are having problems with Graph.pm set the debug
 flag to C<1>. Also Graph.pm will check C<$ENV{TMPDIR}> for the temporary
 file storage. If you do not specify, it will be set to F</tmp>
@@ -211,14 +210,14 @@ purposes by setting C<$Chart::Graph::save_tmpfiles> flag accordingly, C<0>
 (no tmp files saved) or C<1> (save tmp files specified in C<$ENV{TMPDIR)> or
 /tmp by default)
 
-Note: Currently, XRT and Xmgrace use the local x server to draw it's
-graphics by default. With XRT, if you are having problems with color
+Note: Currently, XRT and Xmgrace use the local X server by default to draw
+their graphics. With XRT, if you are having problems with color
 or speed is an issue, set C<$Chart::Graph::use_xvbf> to C<1> to use the
 virtual x frame buffer. With Xmgrace, you MUST set
-C<$Chart::Graph::use_xvbf> to C<1> if you are not using a local x server.
+C<$Chart::Graph::use_xvbf> to C<1> if you are not using a local X server.
 
-All the documentation is also provided in HTML with the sample graphic
-files for Graph.pm are located in the F<doc> directory.
+All the documentation is also provided in HTML with the sample image
+files located in the F<doc> directory.
 
 =head1 CONTENT SUMMARY
 
@@ -228,26 +227,25 @@ files for Graph.pm are located in the F<doc> directory.
  doc/            - documentation in HTML 
  xrt2d/          - xrt2d wrapper executable code
  xrt3d/          - xrt3d wrapper executable code
- test_Graph.pl   - the test script used for debugging
 
 =head1 MORE INFO
 
 For more information on gnuplot, please see the gnuplot web page:
 
- http://www.gnuplot.org/
+ http://www.gnuplot.info/
 
 For more information on Xmgrace, please see the Xmgrace web page:
 
  http://plasma-gate.weizmann.ac.il/Grace
 
-For more information on XRT, please contact Sitraka:
+For more information on XRT, please see the XRT web page:
 
- http://www.sitraka.com
+ http://software.dell.com/products/xrt-pds/
 
 =head1 CONTACT
 
-Send email to graph-dev@caida.org is you have problems, questions,
-or comments. To subscribe to the mailing list send mail to
+Send email to the graph-dev@caida.org mailing list if you have problems,
+questions, or comments. To subscribe to this mailing list send mail to
 graph-dev-request@caida.org with a body of "subscribe your@email.com"
 
 =head1 AUTHOR
@@ -256,8 +254,7 @@ graph-dev-request@caida.org with a body of "subscribe your@email.com"
 
 =head1 SEE ALSO
 
- gnuplot(1).
- xmgrace(1).
- 
+ gnuplot(1)
+ xmgrace(1)
 
 =cut
