@@ -1,7 +1,7 @@
 ## Gnuplot.pm is a sub-module of Graph.pm. It has all the subroutines 
 ## needed for the gnuplot part of the package.
 ##
-## $Id: Gnuplot.pm,v 1.44 2006/04/18 17:56:47 emile Exp $ $Name:  $
+## $Id: Gnuplot.pm,v 1.55 2015/10/05 20:35:33 rkoga Exp $ $Name: Chart-Graph-Release-3-3-1 $
 ##
 ## This software product is developed by Michael Young and David Moore,
 ## and copyrighted(C) 1998 by the University of California, San Diego
@@ -49,12 +49,12 @@ use Chart::Graph::Utils qw(:UTILS);	# get global subs and variable
 use POSIX 'strftime';
 use FileHandle;
 
-$cvs_Id = '$Id: Gnuplot.pm,v 1.44 2006/04/18 17:56:47 emile Exp $';
-$cvs_Author = '$Author: emile $';
-$cvs_Name = '$Name:  $';
-$cvs_Revision = '$Revision: 1.44 $';
+$cvs_Id = '$Id: Gnuplot.pm,v 1.55 2015/10/05 20:35:33 rkoga Exp $';
+$cvs_Author = '$Author: rkoga $';
+$cvs_Name = '$Name: Chart-Graph-Release-3-3-1 $';
+$cvs_Revision = '$Revision: 1.55 $';
 
-$VERSION = 3.0;
+$VERSION = 3.3.1;
 
 use strict;
 
@@ -130,7 +130,7 @@ sub gnuplot {
     
     # check first arg for hash
     if (ref($user_global_opts_ref) ne "HASH") {
-	carp "Global options must be a hash";
+	carp "Global options must be a hash ref";
 	_cleanup_tmpdir();
 	return 0;
     }
@@ -301,23 +301,29 @@ sub gnuplot {
 	    if (defined($value)) { 
 		if (ref($value) eq 'ARRAY') {
 		    # arrayref
-		    print $handle "set $key [$value->[0] : $value->[1]]\n";
+		    print $handle "set $key [$value->[0]:$value->[1]]\n";
 		} else {
 		    # assume string
 		    print $handle "set $key $value\n";
 		}
-	    }
+	    } 
 	}
 	# The only time related Gnuplot code that doesn't need to be
 	# output first.
 	if ($key eq "format") {
 	    if (defined($value)) {
 		if(ref($value) eq "ARRAY") {
+                    my %format_opts = @$value;
+                    foreach my $axis (keys %format_opts) {
 		    # Print value supplying quotes for time format.
-		    print $handle "set $key ", $$value[0]," \"",
-			$$value[1], "\" \n";
+                        if ($axis !~ /^(x|y|x2|y2)$/ ) {
+                            carp "Invalid axis '$axis' for format option, ignoring";
+                            next;
+                        }
+                        print $handle "set format $axis \"$format_opts{$axis}\"\n";
+                    }
 		} else {
-		    carp "Invalid setting for format option";
+		    carp "Invalid setting for format option, please use an array_ref, example: ['x','%.0f']";
 		}
 	    }
 	}
@@ -358,7 +364,7 @@ sub gnuplot {
 	}
 	
 	if ($key eq "output type") {
-	    if (!($value =~ /^(pbm|gif|tgif|png|svg|eps(:? .*)?)$/)) {
+	    if (!($value =~ /^(pbm|gif|tgif|svg|png|eps)( .*)?$/)) {
 		carp "invalid output type: $value";
 		$handle->close();
 		_cleanup_tmpdir();
@@ -368,44 +374,22 @@ sub gnuplot {
 	}
     }
 
-    # create the data file
-    if ($output_type =~ /^eps( .*)?$/) {
-	my $options = $1 || "";
-	if (defined $output_file) {
-	    $plot_file = _make_tmpfile("plot", "eps");
+    my %default_type_options = (
+        'pbm' => 'small color',
+        'png' => 'small',
+    );
+    if ($output_type =~ /^(pbm|gif|tgif|svg|png|eps)( .*)?$/ ) {
+        my $type = $1;
+        $type = 'postscript eps' if ($type eq 'eps');
+        my $options = $2 || $default_type_options{$type} || "";
+        if (defined $output_file) {
+            $plot_file = _make_tmpfile("plot",$type);
 	    print $handle "set output \"$plot_file\"\n";
-	}
-	#print $handle "set terminal postscript eps color \"Arial\" 18\n";
-	print $handle "set terminal postscript eps $options\n";
-    } elsif ($output_type eq "pbm" ) {
-	if (defined $output_file) {
-	    $plot_file = _make_tmpfile("plot", "pbm");
-	    print $handle "set output \"$plot_file\"\n";
-	}
-	print $handle "set terminal pbm small color\n";
-    } elsif ($output_type eq "gif") {
-	# always needs the tempfile because of conversion later on
-	$plot_file = _make_tmpfile("plot", "pbm");
-	print $handle "set output \"$plot_file\"\n";
-	print $handle "set terminal pbm small color\n";
-    } elsif ($output_type eq "png") {
-	if (defined $output_file) {
-	    $plot_file = _make_tmpfile("plot", "png");
-	    print $handle "set output \"$plot_file\"\n";
-	}
-	print $handle "set terminal png small\n";
-    } elsif ($output_type eq "tgif") {
-	if (defined $output_file) {
-	    $plot_file = _make_tmpfile("plot", "obj");
-	    print $handle "set output \"$plot_file\"\n";
-	}
-	print $handle "set terminal tgif\n";
-    } elsif ($output_type eq 'svg') {
-	if (defined $output_file) {
-	    $plot_file = _make_tmpfile("plot", "svg");
-	    print $handle "set output \"$plot_file\"\n";
-	}
-	print $handle "set terminal svg\n";
+        }
+	print $handle "set terminal $type $options\n";
+    } else {
+        # DIE DIE DIE
+        croak "can't happen, output types already checked\n";
     }
 
     # process data sets
@@ -434,19 +418,15 @@ sub gnuplot {
     }	
     
     $handle->close();
-	
-    # gnuplot and convert pbm file to gif
+
+    # gnuplot
     if (not _exec_gnuplot($command_file)) {
 	_cleanup_tmpdir();
 	return 0;
     }
-    
-    if ($output_type eq "gif") {
-	if(not _exec_pbmtogif($plot_file, $output_file)) {
-	    _cleanup_tmpdir();
-	    return 0;
-	}
-    } elsif (defined $output_file && $output_type =~ /^(pbm|eps(?: .*)?|png|tgif)$/) {
+   
+    # removed pbm to gif conversion code here
+    if (defined $output_file && $output_type =~ /^(pbm|eps|svg|png|tgif|gif)/) {
 	#try to get rid of the ugly warnings when moving a file on freebsd
 	if ($^O eq 'freebsd') {
 	    eval { #this is opportunistic, if it fails it doesn't really matter
@@ -571,12 +551,7 @@ sub _set_gnupaths {
 	    return 0;
 	}
     }
-   
-    if (not defined($ppmtogif)) {
-	if (not $ppmtogif = _get_path("ppmtogif")) {
-	    return 0;
-	}
-    }
+    # removed ppmtogif dependency here
     return 1;
 }
 
@@ -606,15 +581,17 @@ sub _print_tics {
 	#tics can come in two formats
 	#this one is [["label1", 10], ["label2", 20],...]
 	if (ref($tic) eq "ARRAY") {
-	    
-	    if ($#{$tic} != 1) {
+	    if (@$tic == 1) {      # Single value
+		push (@tic_array, "$tic->[0]");
+	    } elsif (@$tic == 2) { # Label and value
+		push (@tic_array, "\"$tic->[0]\" $tic->[1]");
+	    } elsif (@$tic == 3) { # Label, value, and tic level
+		push (@tic_array, "\"$tic->[0]\" $tic->[1] $tic->[2]");
+	    } else {
 		carp "invalid tic format";
 		return 0;
 	    }
-	    $tic_label = $tic->[0];
-	    $tic_index = $tic->[1];
-	    push (@tic_array, "\"$tic_label\" $tic_index");
-	    # this one is [10, 20,...]
+	# this one is [10, 20,...]
 	} else {
 	    push (@tic_array, "$tic");
 	}
@@ -761,6 +738,13 @@ sub _file_to_file {
 
 sub _exec_gnuplot {
     my ($command_file) = @_;
+	 ## newer gnuplot will assume you have an X display
+	 ## avaiable if TERM=xterm , make sure this doesn't happen
+	 ### still won't work if DISPLAY is set to something gnuplot
+	 ### can't connect to
+	 if (defined $ENV{'TERM'} && $ENV{'TERM'} =~ /^xterm/ ) { 
+	 	$ENV{'TERM'} = '';
+	 };
     my $status = system("$gnuplot", "$command_file");
     
     if (not _chk_status($status)) {
@@ -770,6 +754,7 @@ sub _exec_gnuplot {
     return 1;
 }	
 
+=cut
 #
 # Subroutine: exec_pbmtogif()
 # 
@@ -794,6 +779,7 @@ sub _exec_pbmtogif {
     
     return 1;
 }
+=cut
 
 #
 # Subroutine: gnuplot_date_utc()
@@ -1039,7 +1025,8 @@ application.
  +----------------+-----------------------------+-----------------------------+
  |'title'         |  set your own title         |     'untitled'              |
  |'output type'   |  'pbm','gif','tgif','png',  |     'png'                   |
- |                |   'svg' or "eps $epsoptions"|                             |
+ |                |   'svg' or 'eps' optionally |                             |
+ |                |   followed by terminal opts |                             |
  |'output file'   |  set your own output file,  |     'untitled-gnuplot.png'  |
  |                |   undef to output to STDOUT |                             |
  |'x-axis label'  |  set your own label         |     'x-axis'                |
@@ -1267,7 +1254,7 @@ and the last is an external data file.
            'logscale y' => '1',
            'output type' => 'png',
            'output file' => 'gnuplot1.png',
-           'xtics' => [ ['small\nfoo', 10], ['medium\nfoo', 20], ['large\nfoo', 30] ],
+	   'xtics' => [ ['minor\\n(no label)', 10, 1], ['explicit\\nmajor', 20, 0], ['default\\nmajor', 30], [40] ],
            'ytics' => [10,20,30,40,50],
            'extra_opts' => 'set key left top Left'},
           [{'title' => 'data1',
@@ -1306,8 +1293,8 @@ C<xdelta>, C<xlow> and C<xhigh>.
      gnuplot({"title" => "Examples of Errorbars",
               "xrange" => "[:11]",
               "yrange" => "[:45]",
-              "output file" => "gnuplot2.gif",
-	      "output type" => "gif",
+              "output file" => "gnuplot2.png",
+	      "output type" => "png",
              },
              # dataset 1
              [{"title" => "yerrorbars",
@@ -1370,8 +1357,8 @@ C<xdelta>, C<xlow> and C<xhigh>.
            );
 
 =for html
-<p><center><img src="gnuplot2.gif"></center></p>
-<p><center><em>gnuplot2.gif</em></center></p>
+<p><center><img src="gnuplot2.png"></center></p>
+<p><center><em>gnuplot2.png</em></center></p>
 
 =head2 PLOTTING DATES - CUSTOM GNUPLOT OPTIONS
 
@@ -1505,8 +1492,8 @@ I<$Chart::Graph::Gnuplot::show_seconds> influence the formatting of the x-tics.
 
     %options = (
                  'title' => 'uts example',
-                 'output file' => 'gnuplot4.gif',
-                 'output type' => 'gif',
+                 'output file' => 'gnuplot4.png',
+                 'output type' => 'png',
                  'x2-axis label' => 'time',
                  'xtics' => [ ['\n9pm UTC', 954795600] ],
                  'ytics' => [10,20,30,40,50],
@@ -1532,8 +1519,8 @@ I<$Chart::Graph::Gnuplot::show_seconds> influence the formatting of the x-tics.
     gnuplot(\%options, $plot);
 
 =for html
-<p><center><img src="gnuplot4.gif"></center></p>
-<p><center><em>gnuplot4.gif</em></center></p>
+<p><center><img src="gnuplot4.png"></center></p>
+<p><center><em>gnuplot4.png</em></center></p>
 
 
 B<Note:> The present implementation of UNIX time stamps only supports
@@ -1584,7 +1571,6 @@ be mixed with other data-types:
 <p><center><img src="gnuplot5.png"></center></p>
 <p><center><em>gnuplot5.png</em></center></p>
 
-
 =head1 MORE INFO
 
 This version of I<Chart::Graph::Gnuplot> was tested against
@@ -1593,11 +1579,11 @@ on older versions of gnuplot.
 
 For more information on gnuplot, please see the gnuplot web page:
 
- http://www.gnuplot.org/
+ http://www.gnuplot.info/
 
 =head1 CONTACT
 
-Send email to graph-dev@caida.org is you have problems, questions,
+Send email to graph-dev@caida.org if you have problems, questions,
 or comments. To subscribe to the mailing list send mail to
 graph-dev-request@caida.org with a body of "subscribe your@email.com"
 
@@ -1607,7 +1593,7 @@ graph-dev-request@caida.org with a body of "subscribe your@email.com"
 
 =head1 SEE ALSO
 
- gnuplot(1).
+ gnuplot(1)
  
 
 =cut
