@@ -1,7 +1,7 @@
 ## Graph.pm is a graphing package that supports on-the-fly graphing 
 ## from the gnuplot, xrt, and xmgrace  graphing packages.
 ##
-## $Id: Utils.pm,v 1.22 2006/04/18 17:56:48 emile Exp $ $Name:  $
+## $Id: Utils.pm,v 1.26 2015/10/05 20:35:33 rkoga Exp $ $Name: Chart-Graph-Release-3-3-1 $
 ##
 ## This software product is developed by Michael Young and David Moore,
 ## and copyrighted(C) 1998 by the University of California, San Diego
@@ -61,12 +61,12 @@ Exporter::export_ok_tags('UTILS');
 use Carp;			# for carp() and croak()
 use File::Path;	                # for rmtree()
 
-$cvs_Id = '$Id: Utils.pm,v 1.22 2006/04/18 17:56:48 emile Exp $';
-$cvs_Author = '$Author: emile $';
-$cvs_Name = '$Name:  $';
-$cvs_Revision = '$Revision: 1.22 $';
+$cvs_Id = '$Id: Utils.pm,v 1.26 2015/10/05 20:35:33 rkoga Exp $';
+$cvs_Author = '$Author: rkoga $';
+$cvs_Name = '$Name: Chart-Graph-Release-3-3-1 $';
+$cvs_Revision = '$Revision: 1.26 $';
 
-$VERSION = 3.0;
+$VERSION = 3.3.1;
 
 use strict;
 
