@@ -1,7 +1,7 @@
 ## Xrt2d.pm is a sub-module of Graph.pm. It has all the subroutines 
 ## needed for the Xrt2d part of the package.
 ##
-## $Id: Xrt2d.pm,v 1.23 2006/04/18 17:56:48 emile Exp $ $Name:  $
+## $Id: Xrt2d.pm,v 1.29 2015/10/06 06:17:14 rkoga Exp $ $Name: Chart-Graph-Release-3-3-1 $
 ##
 ## This software product is developed by Michael Young and David Moore,
 ## and copyrighted(C) 1998 by the University of California, San Diego
@@ -50,12 +50,12 @@ use Carp;			# for carp() and croak()
 use Chart::Graph::Utils qw(:UTILS);	# get global subs and variables
 use Chart::Graph::XrtUtils qw(:UTILS); # get Xrt subroutines
 
-$cvs_Id = '$Id: Xrt2d.pm,v 1.23 2006/04/18 17:56:48 emile Exp $';
-$cvs_Author = '$Author: emile $';
-$cvs_Name = '$Name:  $';
-$cvs_Revision = '$Revision: 1.23 $';
+$cvs_Id = '$Id: Xrt2d.pm,v 1.29 2015/10/06 06:17:14 rkoga Exp $';
+$cvs_Author = '$Author: rkoga $';
+$cvs_Name = '$Name: Chart-Graph-Release-3-3-1 $';
+$cvs_Revision = '$Revision: 1.29 $';
 
-$VERSION = 3.0;
+$VERSION = 3.3.1;
 
 use strict;
 
@@ -692,12 +692,12 @@ Chart::Graph::Xrt2d
 This module is unmaintained, it worked with Sitraka's XRT, and hasn't been
 tested against newer versions.
 
-Sitraka (now Quest) makes a number of graphics packages for UNIX systems.  XRT is
+Sitraka (now Dell) makes a number of graphics packages for UNIX systems.  XRT is
 a Motif-based commercial software product that has been adapted by
 CAIDA using a combination of C drivers and Perl function I<xrt2d()>.
 The Perl function I<xrt2d()> provides access to the two dimensional
 graphing capabilities of XRT from Perl.  To access the three dimensional
-graphing using XRT, use I<xrt3d()> also supplied in the
+graphing using XRT, use I<xrt3d()> which is also supplied in the
 I<Chart::Graph> package.
 
 =head1 ARGUMENTS
@@ -761,7 +761,7 @@ converter packages: I<Imagemagick> and I<Netpbm>.
 If you need to install a converter package, I<Imagemagick>
 I<http://www.imagemagick.org/> is probably preferable
 simply for its comparatively simplicity.  It uses one program
-I<convert> for all of it's conversion needs, so it is easy to manage
+I<convert> for all of its conversion needs, so it is easy to manage
 and simple for Chart::Graph to use.  Many UNIX systems come with some
 collection of the I<Netpbm> utilities already installed, thus users
 may be able to start using Chart::Graph without adding any additional
@@ -842,11 +842,11 @@ unpredicable results.
 
 For more information on XRT:
 
- http://www.quest.com/xrt_pds/
+ http://software.dell.com/products/xrt-pds/
 
 =head1 CONTACT
 
-Send email to graph-dev@caida.org is you have problems, questions,
+Send email to graph-dev@caida.org if you have problems, questions,
 or comments. To subscribe to the mailing list send mail to
 graph-dev-request@caida.org with a body of "subscribe your@email.com"
 
